[![Build Status](https://travis-ci.org/pmatigakis/flask-uauth.svg?branch=develop)](https://travis-ci.org/pmatigakis/flask-uauth)
[![codecov](https://codecov.io/gh/pmatigakis/flask-uauth/branch/develop/graph/badge.svg)](https://codecov.io/gh/pmatigakis/flask-uauth)

Flask-uauth is an extension that adds token based authentication on Flask views.
The main use for flask-uauth is to add authentication on REST api endpoints that 
were created using libraries like flask-restful etc.

Checkout the source code from `https://github.com/pmatigakis/flask-uauth` and
see the scripts in the `examples` folder for instructions on how to use this extension.
